control/deduce_r.hpp

The repetition/deduce_r.hpp header defines a macro to manually deduce the current state of the BOOST_PP_FOR construct.

#### Usage

#include <boost/preprocessor/repetition/deduce_r.hpp>

#### Contents

- BOOST_PP_DEDUCE_R

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)